==> segatex-8.000.tar.gz: segatex-8.000/breakif.sh <==
#
# segatex SELinux tool.
#
# Copyright (C) 2007-2013 Shintaro Fujiwara 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#!/bin/sh 

ERROR=0
LINE=
SOURCEFILE=
ALLIFFILE="../all.if"
STARTFILE="../start_file"
INCLUDEIFFILE="../allif_exclude_myself.txt"
M4_ED_FILE="../all_exclude_myself.if"
INCLUDESPTFILE="../allspt.txt"
INCLUDEFILE="include_if"
INCLUDEFILE2="include_if2"
INCLUDEFILE3="include_if3"
BROKENUPPREPAREFILE="broken_up_prepare"
BROKENUPPREPAREFILE2="broken_up_prepare2"
BROKENUPPREPAREFILE3="broken_up_prepare3"
BROKENUPPREPAREFILE4="broken_up_prepare4"
BROKENUPPREPAREFILE5="broken_up_prepare5"
BROKENUPFILE="broken_up"
BROKENUPFILE2="broken_up2"
NEWFILE="prepare"
CSPLITFILE="xx00"
CSPLITFILE2="xx01"
BLANK=""
TAB="	"

FILELISTPREPARE="filelist_prepare.txt"
FILELIST="filelist.txt"
FILELIST_EXCLUDE_MYSELF="filelist_exclude_myself.txt"
ALL_EXCLUDE_MYSELF_CURRENT_DEFINE="all_exclude_myself_current.if_"
ALL_EXCLUDE_MYSELF_CURRENT="all_exclude_myself_current.if_prepare"

NUM=0

BREAK_IF(){
	find . \( -type f -name "*.if" \) -print | sort > $FILELISTPREPARE && awk -F/ '{print $2}' $FILELISTPREPARE > $FILELIST
	IFS=
	while read LINE
	do
		echo "NUM:"$NUM
		###for debug
		#if [ $NUM -gt 0 ]; then
		#	exit 0	
		#fi

		SOURCEFILE="$LINE"

		if [ ! -r "$SOURCEFILE" ]; then
			echo "Cannot find file $SOURCEFILE" 1>&2
			ERROR=1
		else
			#echo ""
			#echo ""
			NOW_DIR=`pwd | awk -F/ '{print $6}'`
			echo "NOW_DIR is "$NOW_DIR " !"
			echo "SOURCEFILE:"$SOURCEFILE
                	#########################read every files except the file itself#######################
			while read LINE_EXCLUDE
			do 
				if [ "$LINE_EXCLUDE" = "$SOURCEFILE" ]; then
					continue
				fi
					cat "$LINE_EXCLUDE" >> $ALL_EXCLUDE_MYSELF_CURRENT
			done < "$FILELIST"
		fi

		if [ "$NOW_DIR" = "admin" ]; then
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "apps" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "contrib" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "kernel" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "roles" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "services" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "system" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
		fi
		cat zzzzzz $ALL_EXCLUDE_MYSELF_CURRENT > xxxxxx

		`sed 's/interface/define/g' xxxxxx > xxxxxx_define`
		`mv xxxxxx_define ../`

		sed 's/interface(`/thiswillbeconverted::/g' $SOURCEFILE > $SOURCEFILE"_ready"
		sed 's/,`//g' $SOURCEFILE"_ready" > $SOURCEFILE"_ready2"
		sed 's/`//g' $SOURCEFILE"_ready2" > $SOURCEFILE"_ready3"
		sed "s/'//g" $SOURCEFILE"_ready3" > $SOURCEFILE"_ready4"
		cat ../define_file ../start_file $SOURCEFILE"_ready4" > $SOURCEFILE"_ready5"
		m4 $SOURCEFILE"_ready5" > $SOURCEFILE"_ready6"

		STARTED=

		while read LINE2
		do
		if [ "$LINE2" = "## START" ]; then
			STARTED="on"
		fi
		if [ "$STARTED" = "on" ]; then
			echo $LINE2
		fi
		done < $SOURCEFILE"_ready6" > $SOURCEFILE"_ready7"

		cat ../allspt.txt ../start_file $SOURCEFILE"_ready7" > $SOURCEFILE"_ready8"
		sed "s/gen_require/test_require/g" $SOURCEFILE"_ready8" > $SOURCEFILE"_ready9"
		m4 $SOURCEFILE"_ready9" > $SOURCEFILE"_ready10"
		sed "s/test_require/gen_require/g" $SOURCEFILE"_ready10" > $SOURCEFILE"_ready11"
		sed "s/^)//g" $SOURCEFILE"_ready11" > $SOURCEFILE"_ready12"
		STARTED=

		while read LINE3
		do
		if [ "$LINE3" = "## START" ]; then
			STARTED=on
		fi
		if [ "$STARTED" = "on" ]; then
			echo $LINE3
		fi
		done < $SOURCEFILE"_ready12" > $SOURCEFILE"_ready13"
		sed "s/## START//g" $SOURCEFILE"_ready13" > $SOURCEFILE"_ready14"
		sed "s/thiswillbeconverted/interface/g" $SOURCEFILE"_ready14" > $SOURCEFILE"_raw"


		NUM=`expr $NUM + 1`
		unlink zzzzzz
		unlink xxxxxx
		unlink ../xxxxxx_define
		unlink $ALL_EXCLUDE_MYSELF_CURRENT
		unlink $SOURCEFILE"_ready"
		unlink $SOURCEFILE"_ready2"
		unlink $SOURCEFILE"_ready3"
		unlink $SOURCEFILE"_ready4"
		unlink $SOURCEFILE"_ready5"
		unlink $SOURCEFILE"_ready6"
		unlink $SOURCEFILE"_ready7"
		unlink $SOURCEFILE"_ready8"
		unlink $SOURCEFILE"_ready9"
		unlink $SOURCEFILE"_ready10"
		unlink $SOURCEFILE"_ready11"
		unlink $SOURCEFILE"_ready12"
		unlink $SOURCEFILE"_ready13"
		unlink $SOURCEFILE"_ready14"

	done < "$FILELIST"

	
	unlink $FILELISTPREPARE
	unlink $FILELIST
}

cd /usr/share/segatex/raw_if_files

### Get directory name under current directory and put into var.
DICNAME=`find ./ -type d -name "*" | awk -F/ '{ print $2 }' | sort`
### Do something in every directory.

for CHECKDIC in $DICNAME
do
	(\
	cd $CHECKDIC; \
	echo ""
	echo Breaking .if files in $CHECKDIC directory !; \
	echo ""
	BREAK_IF; \
	)
done

echo "Breaking .if scripts Successfully finished."
echo ""
echo "You can see raw .if files in /usr/share/segatex/raw_if_files/"layers" as if_raw files."
echo "You can understand fully the meaning of interfaces of SELinx."


exit $ERROR

==> segatex-8.640.tar.gz: segatex-8.640/breakif.sh <==
#
# segatex SELinux tool.
#
# Copyright (C) 2007-2014 Shintaro Fujiwara 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#!/bin/sh 

ERROR=0
LINE=
SOURCEFILE=
ALLIFFILE="../all.if"
STARTFILE="../start_file"
INCLUDEIFFILE="../allif_exclude_myself.txt"
M4_ED_FILE="../all_exclude_myself.if"
INCLUDESPTFILE="../allspt.txt"
INCLUDEFILE="include_if"
INCLUDEFILE2="include_if2"
INCLUDEFILE3="include_if3"
BROKENUPPREPAREFILE="broken_up_prepare"
BROKENUPPREPAREFILE2="broken_up_prepare2"
BROKENUPPREPAREFILE3="broken_up_prepare3"
BROKENUPPREPAREFILE4="broken_up_prepare4"
BROKENUPPREPAREFILE5="broken_up_prepare5"
BROKENUPFILE="broken_up"
BROKENUPFILE2="broken_up2"
NEWFILE="prepare"
CSPLITFILE="xx00"
CSPLITFILE2="xx01"
BLANK=""
TAB="	"

FILELISTPREPARE="filelist_prepare.txt"
FILELIST0="filelist0.txt"
FILELIST="filelist.txt"
FILELIST_FOR_EXCLUDE="filelist_for_exclude.txt"
FILELIST_EXCLUDE_MYSELF="filelist_exclude_myself.txt"
ALL_EXCLUDE_MYSELF_CURRENT_DEFINE="all_exclude_myself_current.if_"
ALL_EXCLUDE_MYSELF_CURRENT="all_exclude_myself_current.if_prepare"

NUM=0

BREAK_IF(){
	find . \( -type f -name "*.if" \) -print | sort > $FILELISTPREPARE && awk -F/ '{print $2}' $FILELISTPREPARE > $FILELIST0
        cat $FILELIST0 | sed '1i nonexistentfile' > $FILELIST

	IFS=
	while read LINE
	do
		echo "NUM:"$NUM
		###for debug
		#if [ $NUM -gt 0 ]; then
		#	exit 0	
		#fi

		SOURCEFILE="$LINE"

		#if [ ! -r "$SOURCEFILE" ]; then
		#	echo "Cannot find file $SOURCEFILE" 1>&2
	        #	ERROR=1
		#else
			#echo ""
			#echo ""
			NOW_DIR=`pwd | awk -F/ '{print $6}'`
			echo "NOW_DIR is "$NOW_DIR " !"
			echo "SOURCEFILE:"$SOURCEFILE
                	#########################read every files except the file itself#######################
			while read LINE_EXCLUDE
			do 
				if [ "$LINE_EXCLUDE" = "$SOURCEFILE" ]; then
			 		continue
				fi
					cat "$LINE_EXCLUDE" >> $ALL_EXCLUDE_MYSELF_CURRENT
			done < "$FILELIST"
		#fi

		if [ "$NOW_DIR" = "admin" ]; then
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "apps" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "contrib" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "kernel" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "roles" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "system" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "services" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../system/*if >> zzzzzz
		fi
		if [ "$NOW_DIR" = "system" ]; then
			cat ../admin/*if >> zzzzzz
			cat ../apps/*if >> zzzzzz
			cat ../contrib/*if >> zzzzzz
			cat ../kernel/*if >> zzzzzz
			cat ../roles/*if >> zzzzzz
			cat ../services/*if >> zzzzzz
		fi
		cat zzzzzz $ALL_EXCLUDE_MYSELF_CURRENT > xxxxxx

		`sed 's/interface/define/g' xxxxxx > xxxxxx_define`
		`mv xxxxxx_define ../`

		sed 's/interface(`/thiswillbeconverted::/g' $SOURCEFILE > $SOURCEFILE"_ready"
		sed 's/,`//g' $SOURCEFILE"_ready" > $SOURCEFILE"_ready2"
		sed 's/`//g' $SOURCEFILE"_ready2" > $SOURCEFILE"_ready3"
		sed "s/'//g" $SOURCEFILE"_ready3" > $SOURCEFILE"_ready4"
		cat ../define_file ../start_file $SOURCEFILE"_ready4" > $SOURCEFILE"_ready5"
		m4 $SOURCEFILE"_ready5" > $SOURCEFILE"_ready6"

		STARTED=

		while read LINE2
		do
		if [ "$LINE2" = "## START" ]; then
			STARTED="on"
		fi
		if [ "$STARTED" = "on" ]; then
			echo $LINE2
		fi
		done < $SOURCEFILE"_ready6" > $SOURCEFILE"_ready7"

		cat ../allspt.txt ../start_file $SOURCEFILE"_ready7" > $SOURCEFILE"_ready8"
		sed "s/gen_require/test_require/g" $SOURCEFILE"_ready8" > $SOURCEFILE"_ready9"
		m4 $SOURCEFILE"_ready9" > $SOURCEFILE"_ready10"
		sed "s/test_require/gen_require/g" $SOURCEFILE"_ready10" > $SOURCEFILE"_ready11"
		sed "s/^)//g" $SOURCEFILE"_ready11" > $SOURCEFILE"_ready12"
		STARTED=

		while read LINE3
		do
		if [ "$LINE3" = "## START" ]; then
			STARTED=on
		fi
		if [ "$STARTED" = "on" ]; then
			echo $LINE3
		fi
		done < $SOURCEFILE"_ready12" > $SOURCEFILE"_ready13"
		sed "s/## START//g" $SOURCEFILE"_ready13" > $SOURCEFILE"_ready14"
		sed "s/thiswillbeconverted/interface/g" $SOURCEFILE"_ready14" > $SOURCEFILE"_raw"


		NUM=`expr $NUM + 1`
		unlink zzzzzz
		unlink xxxxxx
		unlink ../xxxxxx_define
		unlink $ALL_EXCLUDE_MYSELF_CURRENT
		unlink $SOURCEFILE"_ready"
		unlink $SOURCEFILE"_ready2"
		unlink $SOURCEFILE"_ready3"
		unlink $SOURCEFILE"_ready4"
		unlink $SOURCEFILE"_ready5"
		unlink $SOURCEFILE"_ready6"
		unlink $SOURCEFILE"_ready7"
		unlink $SOURCEFILE"_ready8"
		unlink $SOURCEFILE"_ready9"
		unlink $SOURCEFILE"_ready10"
		unlink $SOURCEFILE"_ready11"
		unlink $SOURCEFILE"_ready12"
		unlink $SOURCEFILE"_ready13"
		unlink $SOURCEFILE"_ready14"

	done < "$FILELIST"

	
	unlink $FILELISTPREPARE
	unlink $FILELIST0
	unlink $FILELIST
}

cd /usr/share/segatex/raw_if_files

### Get directory name under current directory and put into var.
DICNAME=`find ./ -type d -name "*" | awk -F/ '{ print $2 }' | sort`
### Do something in every directory.

for CHECKDIC in $DICNAME
do
	(\
	cd $CHECKDIC; \
	echo ""
	echo Breaking .if files in $CHECKDIC directory !; \
	echo ""
	BREAK_IF; \
	)
done

echo "Breaking .if scripts Successfully finished."
echo ""
echo "You can see raw .if files in /usr/share/segatex/raw_if_files/"layers" as if_raw files."
echo "You can understand fully the meaning of interfaces of SELinx."


exit $ERROR
